.. This is the index used by the readthedocs page. It assumes the
   source/autoapi/Heron/index has been built separately and exists

Heron's documentation!
======================

.. toctree::
    :maxdepth: 2
    :caption: About

    source/about/about_heron

.. toctree::
    :maxdepth: 2
    :caption: Documentation

    source/documentation/installation
    source/documentation/the_editor
    source/documentation/lan_use
    source/documentation/node_types
    source/documentation/adding_repos
    source/documentation/writing_new_nodes
    source/documentation/visualisation
    source/documentation/saving_state
    source/documentation/synchronisation.rst
    source/documentation/debugging

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   source/autoapi/Heron/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
